Identifiable<I> mixin
Entities are VALUES: folds produce new instances; a mutated entity corrupts before/after events and optimistic refolds — enforced here for every class that wears the mixin.
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → I
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
hasSameId(
Identifiable< I> other) → bool -
isSameAs(
Identifiable< I> other) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited